@@ -192,6 +192,8 @@ use strict;
     PVIP_NODE_TW_TMPDIR
     PVIP_NODE_IS_RW
     PVIP_NODE_IS_REF
+    PVIP_NODE_PI
+    PVIP_NODE_E
     PVIP_CATEGORY_UNKNOWN
     PVIP_CATEGORY_STRING
     PVIP_CATEGORY_INT
